@@ -1,17 +1,17 @@
 #[export]
-Sort <- function(x, descending = FALSE, partial = NULL, stable = FALSE, na.last = NULL) {
+Sort <- function(x, descending = FALSE, partial = NULL, stable = FALSE, na.last = NULL, parallel = FALSE) {
   if (stable) {
-    .Call(Rfast_stable_sort, x, descending)
+    .Call(Rfast_stable_sort, x, descending, parallel)
   }
   else if (!is.null(partial)) {
-    .Call(Rfast_partial_sort, x, partial, descending)
+    .Call(Rfast_partial_sort, x, partial, descending, parallel)
   } else if (is.character(x)) {
-    .Call(Rfast_sort_string, x, descending)
+    .Call(Rfast_sort_string, x, descending, parallel)
   } else {
     if (identical(na.last, FALSE)) {
-      .Call(Rfast_Sort_na_first, x, descending)
+      .Call(Rfast_Sort_na_first, x, descending, parallel)
     } else {
-      .Call(Rfast_Sort, x, descending, na.last)
+      .Call(Rfast_Sort, x, descending, na.last, parallel)
     }
   }
 }
@@ -22,13 +22,13 @@ Sort.int <- function(x) {
 }
 
 #[export]
-rowSort <- function(x, descending = FALSE, stable = FALSE, parallel = FALSE) {
-  .Call(Rfast_sort_mat, x, descending, TRUE, stable, parallel)
+rowSort <- function(x, descending = FALSE, stable = FALSE, parallel = FALSE,cores = 0) {
+  .Call(Rfast_sort_mat, x, descending, TRUE, stable, parallel,cores)
 }
 
 #[export]
-colSort <- function(x, descending = FALSE, stable = FALSE, parallel = FALSE) {
-  .Call(Rfast_sort_mat, x, descending, FALSE, stable, parallel)
+colSort <- function(x, descending = FALSE, stable = FALSE, parallel = FALSE,cores = 0) {
+  .Call(Rfast_sort_mat, x, descending, FALSE, stable, parallel,cores)
 }
 
 #[export]
