@@ -1,5 +1,6 @@
+#[export]
 colwatsons <- function(u) {
-  u <- Rfast::sort_mat(u) / (2 * pi)
+  u <- Rfast::colSort(u) / (2 * pi)
   n <- dim(u)[1]
   i <- (1:n)/n
   Wn <- Rfast::rowsums( ( t(u - i + 0.5/n) - Rfast::colsums(u) / n + 0.5 )^2 ) + 1 / ( 12 * n )
