@@ -3,7 +3,7 @@ ginis <- function(x) {
   n <- dim(x)[1]
   x <- Rfast::colSort(x)
   g <- Rfast::eachcol.apply(x, 1:n)
-  g / n / Rfast::colsums(x) - 0.5 * (n + 1)/n
+  2 * g / n / Rfast::colsums(x) - (n + 1)/n
 }
 
 
@@ -12,5 +12,5 @@ gini <-function(x) {
   n <- length(x)
   x <- Rfast::Sort(x)
   g <- sum( x * (1:n) )
-  g / n / sum(x) - 0.5 * (n + 1)/n
+  2 * g / n / sum(x) - (n + 1)/n
 }
