@@ -1,5 +1,6 @@
 // Author: Manos Papadakis
 
+#define ARMA_64BIT_WORD
 #include <RcppArmadillo.h>
 #include "Rfast.h"
 
@@ -68,7 +69,7 @@ colvec pnormc(colvec);
 double sum_abs(mat, mat);
 NumericVector toNumbers(string, const string);
 IntegerVector combine(IntegerVector, IntegerVector);
-arma::Col<int> get_k_indices(rowvec, const int &);
+Col<int> get_k_indices(rowvec, const int &);
 colvec get_k_values(rowvec, const int &);
 bool check_if_is_finite(double);
 IntegerVector Order(NumericVector, const bool, const bool, const bool);
